@@ -2,17 +2,16 @@
 
 import unittest
 
-from bs4 import BeautifulSoup
+import xml.etree.ElementTree as ET
 
 from dwca.read import GBIFResultsReader
 from dwca.darwincore.utils import qualname as qn
 
-from .helpers import _sample_data_path, GBIF_RESULTS_PATH
+from .helpers import GBIF_RESULTS_PATH, MISSINGMETA_PATH
 
 
 class TestGBIFResultsReader(unittest.TestCase):
     """Unit tests for GBIFResultsReader class."""
-    MISSINGMETA_PATH = _sample_data_path('gbif-results-lacks-s-metadata.zip')
 
     CITATIONS_CONTENT = """Please cite this data as follows, and pay attention
  to the rights documented in the rights.txt: blablabla"""
@@ -49,18 +48,18 @@ Rights as supplied: Not supplied"""
             # Assert a key is present
             self.assertTrue('eccf4b09-f0c8-462d-a48c-41a7ce36815a' in
                             results.source_metadata)
-            
+
             self.assertFalse('incorrect-UUID' in results.source_metadata)
 
             # Assert it's the correct EML file (content!)
             sm = results.source_metadata
             metadata = sm['eccf4b09-f0c8-462d-a48c-41a7ce36815a']
 
-            self.assertIsInstance(metadata, BeautifulSoup)
+            self.assertIsInstance(metadata, ET.Element)
 
             # Assert we can read basic fields from EML:
-            self.assertEqual(metadata.dataset.creator.
-                             individualName.givenName.contents[0],
+            self.assertEqual(metadata.find('dataset').find('creator').find('individualName')
+                             .find('givenName').text,
                              'Rob')
 
     def test_row_source_metadata(self):
@@ -68,20 +67,22 @@ Rights as supplied: Not supplied"""
             first_row = results.get_row_by_id('607759330')
             m = first_row.source_metadata
 
-            self.assertIsInstance(m, BeautifulSoup)
-            self.assertEqual(m.dataset.creator.
-                             individualName.givenName.contents[0],
-                             'Stanley')
+            self.assertIsInstance(m, ET.Element)
+
+            v = (m.find('dataset').find('creator').find('individualName')
+                  .find('givenName').text)
+
+            self.assertEqual(v, 'Stanley')
 
             last_row = results.get_row_by_id('782700656')
             m = last_row.source_metadata
 
-            self.assertIsInstance(m, BeautifulSoup)
-            self.assertEqual(m.dataset.language.contents[0],
-                             'en')
+            self.assertIsInstance(m, ET.Element)
+            v = m.find('dataset').find('language').text
+            self.assertEqual(v, 'en')
 
     def test_row_source_missing_metadata(self):
-        with GBIFResultsReader(self.MISSINGMETA_PATH) as results:
+        with GBIFResultsReader(MISSINGMETA_PATH) as results:
             # We have source metadata, but not for all datasets/line...
             # We sould have None in this cases
             first_row = results.get_row_by_id('607759330')
